@@ -1,5 +1,6 @@
 from typing import Dict
 
+from weaverbird.backends.sql_translator.types import SQLQuery
 from weaverbird.pipeline.conditions import (
     ComparisonCondition,
     Condition,
@@ -41,10 +42,16 @@ def apply_condition(condition: Condition, query: str) -> str:
             float(condition.value)
             query += f'{condition.column} {SQL_COMPARISON_OPERATORS[condition.operator]} {condition.value}'
         except ValueError:
+            # just to escape single quotes from crashing the snowflakeSQL query
+            if type(condition.value) == str:
+                condition.value = condition.value.replace('"', '\\"').replace("'", "\\'")
             query += f"{condition.column} {SQL_COMPARISON_OPERATORS[condition.operator]} '{condition.value}'"
     elif isinstance(condition, NullCondition):
         query += f'{condition.column} {SQL_NULLITY_OPERATORS[condition.operator]}'
     elif isinstance(condition, MatchCondition):
+        # just to escape single quotes from crashing the snowflakeSQL query
+        if type(condition.value) == str:
+            condition.value = condition.value.replace('"', '\\"').replace("'", "\\'")
         query += f"{condition.column} {SQL_MATCH_OPERATORS[condition.operator]} '{condition.value}'"
     elif isinstance(condition, InclusionCondition):
         query += f"{condition.column} {SQL_INCLUSION_OPERATORS[condition.operator]} {str(tuple(condition.value))}"
@@ -161,3 +168,25 @@ def prepare_aggregation_query(aggregated_cols, aggregated_string, query, step):
     elif len(aggregated_cols):
         aggregated_string = f"SELECT {', '.join(aggregated_cols)} FROM {query.query_name}"
     return aggregated_string
+
+
+def complete_fields(query: SQLQuery, step=None, columns=None) -> str:
+    """
+    We're going to complete missing field from the query
+
+    """
+    for table in [*query.metadata_manager.tables_metadata]:
+        # TODO : changes the management columns on joins with duplicated columns
+        table_keys = query.metadata_manager.tables_metadata[table].keys()
+        if columns:
+            compiled_query = ', '.join(
+                [
+                    k.strip().replace("-", "_").replace(" ", "").upper()
+                    for k in table_keys
+                    if k.upper() not in columns and k.lower() not in columns
+                ]
+            )
+        else:
+            compiled_query = ', '.join(table_keys)
+
+    return compiled_query
